@@ -30,7 +30,13 @@
 #include <cassert>
 #include <errno.h>
 #include <exception>
+#ifdef USE_FMT_LIBRARY
+#include <fmt/core.h>
+#include <fmt/format.h>
+#include <fmt/xchar.h>
+#else
 #include <format>
+#endif
 #include <fstream>
 #include <filesystem>
 #include <iostream>
@@ -49,6 +55,15 @@
 #include <wchar.h>
 #endif
 
+#ifdef USE_FMT_LIBRARY
+#ifdef _MSC_VER
+#pragma comment(lib, "fmtd.lib")
+#endif
+#if defined(__BORLANDC__)
+#pragma comment(lib, "fmtd.lib")
+#endif
+#endif
+
 extern "C" {
 #ifndef D3D_COMPILE_STANDARD_FILE_INCLUDE
 #define D3D_COMPILE_STANDARD_FILE_INCLUDE ((ID3DInclude*)(UINT_PTR)1)
