@@ -16,7 +16,7 @@ efxc2CompilerAPIContainer::CompilerAPIContainer::CompilerAPIContainer() {
 	h = LoadLibraryEx(DLL_NAME, nullptr, 0);
 	if (h == nullptr) {
 		console.PinkOutput();
-		std::wcerr << std::format(L"{} failed to load ", DLL_NAME);
+		std::wcerr << M_FORMAT(L"{} failed to load ", DLL_NAME);
 		std::cerr << std::endl;
 		console.ResetOutput();
 		efxc2Utils::print_windows_error();
@@ -32,7 +32,7 @@ efxc2CompilerAPIContainer::CompilerAPIContainer::CompilerAPIContainer() {
 #endif
 	if (ptr_D3DCompile2 == nullptr) {
 		console.PinkOutput();
-		std::cerr << std::format(ERR_LOAD_FCN, FCN_D3DCompile2);
+		std::cerr << M_FORMAT(ERR_LOAD_FCN, FCN_D3DCompile2);
 		console.ResetOutput();
 		efxc2Utils::print_windows_error();
 		throw efxc2Exception::Win32APIFailure();
@@ -40,7 +40,7 @@ efxc2CompilerAPIContainer::CompilerAPIContainer::CompilerAPIContainer() {
 	ptr_D3DStripShader = std::bit_cast<pD3DStripShaderg>(GetProcAddress(h, FCN_D3DStripShader)); 
 	if (ptr_D3DStripShader == nullptr) {
 		console.PinkOutput();
-		std::cerr << std::format(ERR_LOAD_FCN, FCN_D3DStripShader);
+		std::cerr << M_FORMAT(ERR_LOAD_FCN, FCN_D3DStripShader);
 		console.ResetOutput();
 		efxc2Utils::print_windows_error();
 		throw efxc2Exception::Win32APIFailure();
@@ -48,7 +48,7 @@ efxc2CompilerAPIContainer::CompilerAPIContainer::CompilerAPIContainer() {
 	ptr_D3DGetBlobPart = std::bit_cast<pD3DGetBlobPartg>(GetProcAddress(h, FCN_D3DGetBlobPart));
 	if (ptr_D3DGetBlobPart == nullptr) {
 		console.PinkOutput();
-		std::cerr << std::format(ERR_LOAD_FCN, FCN_D3DGetBlobPart);
+		std::cerr << M_FORMAT(ERR_LOAD_FCN, FCN_D3DGetBlobPart);
 		console.ResetOutput();
 		efxc2Utils::print_windows_error();
 		throw efxc2Exception::Win32APIFailure();
@@ -56,7 +56,7 @@ efxc2CompilerAPIContainer::CompilerAPIContainer::CompilerAPIContainer() {
 	ptr_D3DSetBlobPart = std::bit_cast<pD3DSetBlobPartg>(GetProcAddress(h, FCN_D3DSetBlobPart));
 	if (ptr_D3DSetBlobPart == nullptr) {
 		console.PinkOutput();
-		std::cerr << std::format(ERR_LOAD_FCN, FCN_D3DSetBlobPart);
+		std::cerr << M_FORMAT(ERR_LOAD_FCN, FCN_D3DSetBlobPart);
 		console.ResetOutput();
 		efxc2Utils::print_windows_error();
 		throw efxc2Exception::Win32APIFailure();
@@ -64,7 +64,7 @@ efxc2CompilerAPIContainer::CompilerAPIContainer::CompilerAPIContainer() {
 	ptr_D3DDisassemble = std::bit_cast<pD3DDisassembleg>(GetProcAddress(h, FCN_D3DDisassemble)); 
 	if (ptr_D3DDisassemble == nullptr) {
 		console.PinkOutput();
-		std::cerr << std::format(ERR_LOAD_FCN, FCN_D3DDisassemble);
+		std::cerr << M_FORMAT(ERR_LOAD_FCN, FCN_D3DDisassemble);
 		console.ResetOutput();
 		efxc2Utils::print_windows_error();
 		throw efxc2Exception::Win32APIFailure();
@@ -72,7 +72,7 @@ efxc2CompilerAPIContainer::CompilerAPIContainer::CompilerAPIContainer() {
 	ptr_D3DLoadModule = std::bit_cast<gD3DLoadModulep>(GetProcAddress(h, FCN_D3DLoadModule)); 
 	if (ptr_D3DLoadModule == nullptr) {
 		console.PinkOutput();
-		std::cerr << std::format(ERR_LOAD_FCN, FCN_D3DLoadModule);
+		std::cerr << M_FORMAT(ERR_LOAD_FCN, FCN_D3DLoadModule);
 		console.ResetOutput();
 		efxc2Utils::print_windows_error();
 		throw efxc2Exception::Win32APIFailure();
@@ -80,7 +80,7 @@ efxc2CompilerAPIContainer::CompilerAPIContainer::CompilerAPIContainer() {
 	ptr_D3DCreateLinker = std::bit_cast<gD3DCreateLinkerp>(GetProcAddress(h, FCN_D3DCreateLinker));
 	if (ptr_D3DCreateLinker == nullptr) {
 		console.PinkOutput();
-		std::cerr << std::format(ERR_LOAD_FCN, FCN_D3DCreateLinker);
+		std::cerr << M_FORMAT(ERR_LOAD_FCN, FCN_D3DCreateLinker);
 		console.ResetOutput();
 		efxc2Utils::print_windows_error();
 		throw efxc2Exception::Win32APIFailure();
@@ -88,7 +88,7 @@ efxc2CompilerAPIContainer::CompilerAPIContainer::CompilerAPIContainer() {
 	ptr_D3DCreateFunctionLinkingGraph = std::bit_cast<gD3DCreateFunctionLinkingGraphp>(GetProcAddress(h, FCN_D3DCreateFunctionLinkingGraph));
 	if (ptr_D3DCreateFunctionLinkingGraph == nullptr) {
 		console.PinkOutput();
-		std::cerr << std::format(ERR_LOAD_FCN, FCN_D3DCreateFunctionLinkingGraph);
+		std::cerr << M_FORMAT(ERR_LOAD_FCN, FCN_D3DCreateFunctionLinkingGraph);
 		console.ResetOutput();
 		efxc2Utils::print_windows_error();
 		throw efxc2Exception::Win32APIFailure();
@@ -96,7 +96,7 @@ efxc2CompilerAPIContainer::CompilerAPIContainer::CompilerAPIContainer() {
 	ptr_D3DPreprocess = std::bit_cast<gD3DPreprocessp>(GetProcAddress(h, FCN_D3DPreprocess));
 	if (ptr_D3DPreprocess == nullptr) {
 		console.PinkOutput();
-		std::cerr << std::format(ERR_LOAD_FCN, FCN_D3DPreprocess);
+		std::cerr << M_FORMAT(ERR_LOAD_FCN, FCN_D3DPreprocess);
 		console.ResetOutput();
 		efxc2Utils::print_windows_error();
 		throw efxc2Exception::Win32APIFailure();
